#!/usr/bin/env python3
#-*- coding: utf-8 -*-
#
# GtkFalse - gtkfalse
# http://www.florian-diesch.de/software/gtkfalse/
#
# Copyright (C) 2014 Florian Diesch <devel@florian-diesch.de>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import glob, sys

from setuptools import setup, find_packages

if sys.version_info[:2] < (3, 2):
    raise RuntimeError('Python 3.2 or newer required')

try:
    from DistUtilsExtra.command import *
except ImportError:
    raise RuntimeError('To build GtkFalse you need https://launchpad.net/python-distutils-extra')

def read_from_file(path):
    with open(path) as input:
        return input.read()

import  _meta
    
setup(
    name='gtkfalse',
    version=_meta.VERSION,
    packages=find_packages(),
    include_package_data=True,
    maintainer='Florian Diesch',
    maintainer_email='devel@florian-diesch.de',
    author = "Florian Diesch",
    author_email = "devel@florian-diesch.de",    
    description='gtkfalse - a GUI version of /bin/false',
    long_description=read_from_file('README.txt'),
    data_files=[
        ('/usr/share/applications',
         glob.glob('data/desktop/*.desktop')),
        ('share/gtkfalse/ui/',
         glob.glob('data/ui/*.ui')),
        ('/usr/share/icons/hicolor/scalable/apps/',
         glob.glob('data/icons/*.svg')),
        ],
    entry_points = {
        'console_scripts': ['gtkfalse=gtkfalse:main'],
        },
    license='GPLv3',
    url='http://www.florian-diesch.de/software/gtkfalse/',
    download_url='http://www.florian-diesch.de/software/gtkfalse/',
    keywords = "", 
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: X11 Applications :: GTK',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Natural Language :: German',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3',
        'Topic :: Office/Business',
        'Topic :: Other/Nonlisted Topic',
        'Topic :: Utilities',
        ],
    cmdclass = { "build" : build_extra.build_extra,
                 "build_i18n" :  build_i18n.build_i18n,
                 "build_help" :  build_help.build_help,
                 "build_icons" :  build_icons.build_icons }

    )
